# Dumbo Architettura degli Elaboratori

Una semplice interfaccia a linea di comando per il corso di Architettura degli Eleboratori.


## Prerequisiti

Python 3.10+

## Installazione

Il modo più semplice è usare pip:

```bash
$ pip3 install dumbo-ae
```


## Uso

Per controllare la propria soluzione a un esercizio è necessario indicare l'UUID dell'esercizio (fornito in aula) e il file sorgente della propria soluzione: 
```bash
$ python3 -m dumbo_ae checker --of <UUID> <file-sorgente>
```
